@@ -5,7 +5,7 @@ import click
 import yaml
 
 from ..cli_constants import BUILD_DIR, IMAGE_TAG_TO_REPLACE
-from ..cli_utils import echo_error, echo_info, echo_warning
+from ..cli_utils import echo_info, echo_warning
 from ..config_generation import (
     copy_config_dir_to_build_dir,
     copy_dag_dir_to_build_dir,
@@ -14,11 +14,7 @@ from ..config_generation import (
 from ..data_structures import DockerArgs
 from ..dbt_utils import read_dbt_vars_from_configs, run_dbt_command
 from ..docker_response_reader import DockerResponseReader
-from ..errors import (
-    DataPipelinesError,
-    DockerErrorResponseError,
-    DockerNotInstalledError,
-)
+from ..errors import DockerErrorResponseError, DockerNotInstalledError
 from ..io_utils import replace
 from ..jinja import replace_vars_with_values
 
@@ -31,22 +27,19 @@ def _docker_build(docker_args: DockerArgs) -> None:
     """
     try:
         import docker
+        import docker.errors
     except ModuleNotFoundError:
         raise DockerNotInstalledError()
 
     echo_info("Building Docker image")
     docker_client = docker.from_env()
     docker_tag = docker_args.docker_build_tag()
-    _, logs_generator = docker_client.images.build(path=".", tag=docker_tag)
     try:
+        _, logs_generator = docker_client.images.build(path=".", tag=docker_tag)
         DockerResponseReader(logs_generator).click_echo_ok_responses()
-    except DockerErrorResponseError as err:
-        echo_error(err.message)
-        raise DataPipelinesError(
-            "Error raised when pushing Docker image. Ensure that "
-            "Docker image you try to push exists. Maybe try running "
-            "'dp compile' first?"
-        )
+    except docker.errors.BuildError as err:
+        build_log = "\n".join([str(log) for log in err.build_log])
+        raise DockerErrorResponseError(f"{err.msg}\n{build_log}")
 
 
 def _dbt_compile(env: str) -> None:
